@@ -1,2 +1,2 @@
-# -*- coding: utf-8 -*-
 from simple_avk.AVK import SimpleAVK
+from simple_avk.AVK import VKError
